@@ -206,10 +206,12 @@ class ListsContainer:
         def load():
             if genre_ids is None:
                 return ([], [])
+            elif App().settings.get_value("show-performers"):
+                artists = App().artists.get_all(genre_ids)
             else:
                 artists = App().artists.get(genre_ids)
-                compilations = App().albums.get_compilation_ids(genre_ids)
-                return (artists, compilations)
+            compilations = App().albums.get_compilation_ids(genre_ids)
+            return (artists, compilations)
 
         def setup(artists, compilations):
             mask = SelectionListMask.ARTISTS
@@ -261,7 +263,7 @@ class ListsContainer:
         if selected_ids[0] == Type.PLAYLISTS:
             view = self._get_view_playlists()
         elif selected_ids[0] == Type.CURRENT:
-            view = self._get_view_current()
+            view = self.get_view_current()
         elif selected_ids[0] == Type.SEARCH:
             view = self._get_view_search()
         elif Type.DEVICES - 999 < selected_ids[0] < Type.DEVICES:
