@@ -97,14 +97,12 @@ class AlbumsDatabase:
             @warning: commit needed
         """
         with SqlCursor(App().db, True) as sql:
-            currents = self.get_artist_ids(album_id)
-            if not currents or set(currents) - set(artist_ids):
-                sql.execute("DELETE FROM album_artists\
-                            WHERE album_id=?", (album_id,))
-                for artist_id in artist_ids:
-                    sql.execute("INSERT INTO album_artists\
-                                (album_id, artist_id)\
-                                VALUES (?, ?)", (album_id, artist_id))
+            sql.execute("DELETE FROM album_artists\
+                        WHERE album_id=?", (album_id,))
+            for artist_id in artist_ids:
+                sql.execute("INSERT INTO album_artists\
+                            (album_id, artist_id)\
+                            VALUES (?, ?)", (album_id, artist_id))
 
     def set_synced(self, album_id, synced):
         """
@@ -613,11 +611,6 @@ class AlbumsDatabase:
             @return [int]
         """
         genre_ids = remove_static_genres(genre_ids)
-        # Reset filters if not needed
-        if not self.__has_genres(album_id):
-            genre_ids = []
-        if not self.__has_artists(album_id):
-            artist_ids = []
         with SqlCursor(App().db) as sql:
             filters = (album_id, disc)
             request = "SELECT DISTINCT tracks.rowid\
@@ -935,25 +928,24 @@ class AlbumsDatabase:
                 result = sql.execute(request, filter)
             return list(itertools.chain(*result))
 
-    def search(self, string, limit=25):
+    def search(self, searched):
         """
             Search for albums looking like string
             @param search as str
-            @param limit as int/None
             @return album ids as [int]
         """
+        no_accents = noaccents(searched)
         with SqlCursor(App().db) as sql:
-            if limit is None:
-                filters = ("%" + noaccents(string) + "%",)
-            else:
-                filters = ("%" + noaccents(string) + "%", limit)
-            request = ("SELECT albums.rowid\
-                       FROM albums\
-                       WHERE noaccents(name) LIKE ?")
-            if limit is not None:
-                request += " LIMIT ?"
-            result = sql.execute(request, filters)
-            return list(itertools.chain(*result))
+            items = []
+            for filter in [(no_accents + "%",),
+                           ("%" + no_accents,),
+                           ("%" + no_accents + "%",)]:
+                result = sql.execute("SELECT albums.rowid\
+                                      FROM albums\
+                                      WHERE noaccents(name) LIKE ? LIMIT 25",
+                                     filter)
+                items += list(itertools.chain(*result))
+            return items
 
     def calculate_artist_ids(self, album_id):
         """
@@ -1056,34 +1048,3 @@ class AlbumsDatabase:
 #######################
 # PRIVATE             #
 #######################
-    def __has_genres(self, album_id):
-        """
-            Return True if album has more than one genre
-            @param album id as int
-            @return bool
-        """
-        with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT COUNT(*)\
-                                 FROM album_genres\
-                                 WHERE album_id=?\
-                                 LIMIT 2", (album_id,))
-            v = result.fetchone()
-            if v is not None:
-                return v[0] > 1
-        return False
-
-    def __has_artists(self, album_id):
-        """
-            Return True if album has more than one artist
-            @param album id as int
-            @return bool
-        """
-        with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT COUNT(*)\
-                                 FROM album_artists\
-                                 WHERE album_id=?\
-                                 LIMIT 2", (album_id,))
-            v = result.fetchone()
-            if v is not None:
-                return v[0] > 1
-        return False
