@@ -16,7 +16,6 @@ from datetime import datetime
 from gettext import gettext as _
 
 from lollypop.define import App, ArtSize, ViewType
-from lollypop.view_albums_list import AlbumsListView
 from lollypop.helper_art import ArtHelperEffect
 from lollypop.controller_information import InformationController
 from lollypop.controller_playback import PlaybackController
@@ -67,6 +66,7 @@ class FullScreen(Gtk.Window, InformationController,
             self.__artsize = int(ArtSize.FULLSCREEN * geometry.width / 1920)
         self.__font_size = int(14 * geometry.height / 1080)
         widget = builder.get_object("widget")
+        grid = builder.get_object("grid")
         self._play_button = builder.get_object("play_btn")
         self._next_button = builder.get_object("next_btn")
         self._prev_button = builder.get_object("prev_btn")
@@ -76,10 +76,10 @@ class FullScreen(Gtk.Window, InformationController,
         preferences = Gio.Settings.new("org.gnome.desktop.wm.preferences")
         layout = preferences.get_value("button-layout").get_string()
         if layout.split(":")[0] == "close":
-            widget.attach(close_btn, 0, 0, 1, 1)
+            grid.attach(close_btn, 0, 0, 1, 1)
             close_btn.set_property("halign", Gtk.Align.START)
         else:
-            widget.attach(close_btn, 2, 0, 1, 1)
+            grid.attach(close_btn, 2, 0, 1, 1)
             close_btn.set_property("halign", Gtk.Align.END)
         self._artwork = builder.get_object("cover")
         if rotate_album:
@@ -97,7 +97,8 @@ class FullScreen(Gtk.Window, InformationController,
         self.connect("key-release-event", self.__on_key_release_event)
 
         # Add an AlbumListView on the right
-        self.__view = AlbumsListView(ViewType.DND)
+        self.__view = App().window.container.get_view_current(
+            ViewType.DND | ViewType.FULLSCREEN)
         self.__view.get_style_context().add_class("background-opacity")
         self.__view.show()
         self.__revealer.add(self.__view)
@@ -116,7 +117,6 @@ class FullScreen(Gtk.Window, InformationController,
                                                  self.__on_party_changed)
         self.on_status_changed(App().player)
         self.on_current_changed(App().player)
-        self.__view.populate(App().player.albums)
         Gtk.Window.do_show(self)
         if self.__timeout_id is None:
             try:
