@@ -430,8 +430,8 @@ class MPRIS(Server):
                 self.__rating / 5)
             if App().player.current_track.id == Type.RADIOS:
                 cover_path = App().art.get_radio_cache_path(
-                    ", ".join(App().player.current_track.artists),
-                    ArtSize.MONSTER)
+                    App().player.current_track.radio_name,
+                    ArtSize.MONSTER, ArtSize.MONSTER)
             else:
                 cover_path = App().art.get_album_cache_path(
                     App().player.current_track.album,
