@@ -12,15 +12,14 @@
 
 from gi.repository import Gtk, GLib
 
-from gettext import gettext as _
-
 from lollypop.define import App, Type
 from lollypop.view_flowbox import FlowBoxView
 from lollypop.widgets_radio import RadioWidget
 from lollypop.radios import Radios
 from lollypop.pop_tunein import TuneinPopover
 from lollypop.controller_view import ViewController, ViewControllerType
-from lollypop.view import MessageView
+from lollypop.shown import ShownLists
+from lollypop.utils import get_icon_name
 
 
 class RadiosView(FlowBoxView, ViewController):
@@ -35,6 +34,8 @@ class RadiosView(FlowBoxView, ViewController):
         FlowBoxView.__init__(self)
         ViewController.__init__(self, ViewControllerType.RADIO)
         self._widget_class = RadioWidget
+        self._empty_message = ShownLists.IDS[Type.RADIOS][0]
+        self._empty_icon_name = get_icon_name(Type.RADIOS)
         self.__radios = Radios()
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/RadiosView.ui")
@@ -49,13 +50,7 @@ class RadiosView(FlowBoxView, ViewController):
             Add radio widgets
             @param radio_ids as [int]
         """
-        if radio_ids:
-            FlowBoxView.populate(self, radio_ids)
-        else:
-            self._scrolled.hide()
-            view = MessageView(_("No favorite radios"))
-            view.show()
-            self.add(view)
+        FlowBoxView.populate(self, radio_ids)
 
 #######################
 # PROTECTED           #
@@ -66,6 +61,7 @@ class RadiosView(FlowBoxView, ViewController):
             Start lazy loading
             @param radio ids as [int]
         """
+        self._remove_placeholder()
         widget = FlowBoxView._add_items(self, radio_ids, self.__radios)
         if widget is not None:
             widget.connect("overlayed", self.on_overlayed)
@@ -122,16 +118,6 @@ class RadiosView(FlowBoxView, ViewController):
 #######################
 # PRIVATE             #
 #######################
-    def __add_radio(self, radio_id):
-        """
-            Add radio
-            @param radio_id as int
-        """
-        widget = RadioWidget(radio_id, self.__radios)
-        self._box.insert(widget, 0)
-        widget.populate()
-        widget.show()
-
     def __on_radio_changed(self, radios, radio_id):
         """
             Update view based on radio_id status
@@ -146,7 +132,7 @@ class RadiosView(FlowBoxView, ViewController):
                     item = child
                     break
             if item is None:
-                self.__add_radio(radio_id)
+                self._add_items([radio_id])
             else:
                 name = self.__radios.get_name(radio_id)
                 item.rename(name)
