@@ -24,10 +24,11 @@ class Row(Gtk.ListBoxRow):
         A row
     """
 
-    def __init__(self, track, view_type):
+    def __init__(self, track, album_artist_ids, view_type):
         """
             Init row widgets
             @param track as Track
+            @param album_artist_ids as [int]
             @param view_type as ViewType
         """
         # We do not use Gtk.Builder for speed reasons
@@ -35,23 +36,30 @@ class Row(Gtk.ListBoxRow):
         self._view_type = view_type
         self._artists_label = None
         self._track = track
+        self.__filtered = False
         self._indicator = IndicatorWidget(self, view_type)
         self._row_widget = Gtk.EventBox()
         self._row_widget.connect("destroy", self._on_destroy)
-        self._row_widget.connect("button-release-event",
-                                 self.__on_button_release_event)
+        self.__gesture = Gtk.GestureLongPress.new(self._row_widget)
+        self.__gesture.connect("pressed", self.__on_gesture_pressed)
+        self.__gesture.connect("end", self.__on_gesture_end)
+        # We want to get release event after gesture
+        self.__gesture.set_propagation_phase(Gtk.PropagationPhase.CAPTURE)
+        self.__gesture.set_button(0)
         self._grid = Gtk.Grid()
         self._grid.set_property("valign", Gtk.Align.CENTER)
         self._grid.set_column_spacing(5)
         self._row_widget.add(self._grid)
-        self._title_label = Gtk.Label.new(self._track.name)
+        self._title_label = Gtk.Label.new(
+            GLib.markup_escape_text(self._track.name))
+        self._title_label.set_use_markup(True)
         self._title_label.set_property("has-tooltip", True)
         self._title_label.connect("query-tooltip", on_query_tooltip)
         self._title_label.set_property("hexpand", True)
         self._title_label.set_property("halign", Gtk.Align.START)
         self._title_label.set_property("xalign", 0)
         self._title_label.set_ellipsize(Pango.EllipsizeMode.END)
-        featuring_artist_ids = track.featuring_artist_ids
+        featuring_artist_ids = track.get_featuring_artist_ids(album_artist_ids)
         if featuring_artist_ids:
             artists = []
             for artist_id in featuring_artist_ids:
@@ -83,14 +91,14 @@ class Row(Gtk.ListBoxRow):
         if self._view_type & ViewType.DND and\
                 self._view_type & ViewType.POPOVER:
             self.__action_button = Gtk.Button.new_from_icon_name(
-                "list-remove-symbolic",
-                Gtk.IconSize.MENU)
+               "list-remove-symbolic",
+               Gtk.IconSize.MENU)
             self.__action_button.set_tooltip_text(
-                _("Remove from playback"))
+               _("Remove from playback"))
         elif not self._view_type & (ViewType.POPOVER | ViewType.SEARCH):
             self.__action_button = Gtk.Button.new_from_icon_name(
-                "view-more-symbolic",
-                Gtk.IconSize.MENU)
+               "view-more-symbolic",
+               Gtk.IconSize.MENU)
         else:
             self.__action_button = None
         if self.__action_button is not None:
@@ -156,6 +164,26 @@ class Row(Gtk.ListBoxRow):
             self._num_label.get_style_context().remove_class("queued")
             self._num_label.set_text("")
 
+    def set_filtered(self, b):
+        """
+            Set widget filtered
+            @param b as bool
+            @return bool (should be shown)
+        """
+        self.__filtered = b
+        if b:
+            self.set_state_flags(Gtk.StateFlags.NORMAL, True)
+        else:
+            self.set_state_flags(Gtk.StateFlags.VISITED, True)
+        return True
+
+    @property
+    def filtered(self):
+        """
+            True if filtered by parent
+        """
+        return self.__filtered
+
     @property
     def row_widget(self):
         """
@@ -188,10 +216,10 @@ class Row(Gtk.ListBoxRow):
 #######################
 # PRIVATE             #
 #######################
-    def __popup_menu(self, eventbox, xcoordinate=None, ycoordinate=None):
+    def __popup_menu(self, widget, xcoordinate=None, ycoordinate=None):
         """
             Popup menu for track
-            @param eventbox as Gtk.EventBox
+            @param widget as Gtk.Widget
             @param xcoordinate as int (or None)
             @param ycoordinate as int (or None)
         """
@@ -216,34 +244,23 @@ class Row(Gtk.ListBoxRow):
         else:
             popover = TrackMenuPopover(self._track, self._get_menu())
         if xcoordinate is not None and ycoordinate is not None:
-            rect = eventbox.get_allocation()
+            rect = widget.get_allocation()
             rect.x = xcoordinate
             rect.y = ycoordinate
             rect.width = rect.height = 1
             popover.set_pointing_to(rect)
-        popover.set_relative_to(eventbox)
+        popover.set_relative_to(widget)
         popover.connect("closed", on_closed)
         self.get_style_context().add_class("track-menu-selected")
         popover.popup()
 
-    def __on_artist_button_press(self, eventbox, event):
-        """
-            Go to artist page
-            @param eventbox as Gtk.EventBox
-            @param event as Gdk.EventButton
-        """
-        App().window.container.show_artists_albums(self._album.artist_ids)
-        return True
-
     def __on_button_release_event(self, widget, event):
         """
-            Handle button press event:
-                |_ 1 => activate
-                |_ 2 => queue
-                |_ 3 => menu
+            Handle button release event
             @param widget as Gtk.Widget
-            @param event as Gdk.EventButton
+            @param event as Gdk.Event
         """
+        widget.disconnect_by_func(self.__on_button_release_event)
         if event.state & Gdk.ModifierType.CONTROL_MASK and\
                 self._view_type & ViewType.DND:
             if self.get_state_flags() & Gtk.StateFlags.SELECTED:
@@ -255,7 +272,7 @@ class Row(Gtk.ListBoxRow):
                 self._view_type & ViewType.DND:
             self.emit("do-selection")
         elif event.button == 3:
-            self.__popup_menu(widget, event.x, event.y)
+            self.__popup_menu(self, event.x, event.y)
         elif event.button == 2:
             if self._track.id in App().player.queue:
                 App().player.remove_from_queue(self._track.id)
@@ -269,12 +286,37 @@ class Row(Gtk.ListBoxRow):
             self.activate()
         return True
 
+    def __on_gesture_pressed(self, gesture, x, y):
+        """
+            Show current track menu
+            @param gesture as Gtk.GestureLongPress
+            @param x as float
+            @param y as float
+        """
+        if self._view_type & ViewType.DND and\
+                self._view_type & ViewType.POPOVER:
+            self._track.album.remove_track(self._track)
+            self.destroy()
+        else:
+            self.__popup_menu(self, x, y)
+
+    def __on_gesture_end(self, gesture, sequence):
+        """
+            Connect button release event
+            Here because we only want this if a gesture was recognized
+            This allow touch scrolling
+        """
+        self._row_widget.connect("button-release-event",
+                                 self.__on_button_release_event)
+
     def __on_action_button_release_event(self, button, event):
         """
-            Show row menu
+           Show row menu
             @param button as Gtk.Button
             @param event as Gdk.EventButton
         """
+        if not self.get_state_flags() & Gtk.StateFlags.PRELIGHT:
+            return
         if self._view_type & ViewType.DND and\
                 self._view_type & ViewType.POPOVER:
             self._track.album.remove_track(self._track)
