@@ -145,14 +145,14 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
             App().set_accels_for_action("app.seek(-10)",
                                         ["<Shift><Alt>Right"])
             App().set_accels_for_action("app.shortcut::go_back",
-                                        ["<Alt>Right"])
+                                        ["<Alt>Right", "Back"])
         else:
             App().set_accels_for_action("app.seek(10)",
                                         ["<Shift><Alt>Right"])
             App().set_accels_for_action("app.seek(-10)",
                                         ["<Shift><Alt>Left"])
             App().set_accels_for_action("app.shortcut::go_back",
-                                        ["<Alt>Left"])
+                                        ["<Alt>Left", "Back"])
         App().set_accels_for_action("app.shortcut::play_pause",
                                     ["space", "<Alt>c"])
         App().set_accels_for_action("app.shortcut::play", ["<Alt>x"])
@@ -315,12 +315,6 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
             @param width as int
             @param height as int
         """
-        if self.__miniplayer is not None:
-            if height < Sizing.SMALL and\
-                    App().player.current_track.id is not None:
-                self.__miniplayer.reveal()
-            self.__miniplayer.show_reveal_button(height >= Sizing.SMALL)
-
         if width < Sizing.MONSTER:
             self.__show_miniplayer(True)
         else:
